/******************************************************************************
*
* project name:    TI-Chess
* file name:       generic.c
* initial date:    13/07/2000
* authors:         thomas.nussbaumer@gmx.net (coding)
*                  marcos.lopez@wol.es (design/graphics/beta testing)
* description:     generic drawing routines
*
* $Id: generic.c,v 1.2 2000/08/12 15:31:12 Thomas Nussbaumer Exp $
*
******************************************************************************/

#include "generic.h"



/*===========================================================================*/
/* draw a line with given color from (x0,y0) to (x1,y1)                      */
/*===========================================================================*/
void DrawColorLine(int x0,int y0,int x1, int y1, int color) {
    SetPlane(LIGHT_PLANE);
    if (color == COLOR_WHITE || color == COLOR_DARKGRAY) {
        DrawLine(x0, y0, x1, y1, A_REVERSE);
    }
    else {
        DrawLine(x0, y0, x1, y1, A_NORMAL);
    }
    SetPlane(DARK_PLANE);
    if (color == COLOR_WHITE || color == COLOR_LIGHTGRAY) {
        DrawLine(x0, y0, x1, y1, A_REVERSE);
    }
    else {
        DrawLine(x0, y0, x1, y1, A_NORMAL);
    }
}



/*===========================================================================*/
/* draws a rectangle with given color                                        */
/* if fill == 1) the rectangle is filled                                     */
/*===========================================================================*/
void DrawColorRect(int x0,int y0,int x1, int y1, int color,int fill) {
    WIN_RECT wrect;
    SCR_RECT rect;
    void     (*df)(void*,void*,int);
    void*    parea;

    if (fill) {
        rect.xy.x0 = x0;
        rect.xy.y0 = y0;
        rect.xy.x1 = x1;
        rect.xy.y1 = y1;
        parea      = &rect;
        df         = (void(*)(void*,void*,int))ScrRectFill;
    }
    else {
        wrect.x0 = x0;
        wrect.y0 = y0;
        wrect.x1 = x1;
        wrect.y1 = y1;
        parea    = &wrect;
        df       = (void(*)(void*,void*,int))DrawClipRect;
    }

    SetPlane(LIGHT_PLANE);
    if (color == COLOR_WHITE || color == COLOR_DARKGRAY) {
        (*df)(parea,&fullscreen, A_REVERSE);
    }
    else {
        (*df)(parea,&fullscreen, A_NORMAL);
    }
    SetPlane(DARK_PLANE);
    if (color == COLOR_WHITE || color == COLOR_LIGHTGRAY) {
        (*df)(parea,&fullscreen, A_REVERSE);
    }
    else {
        (*df)(parea,&fullscreen, A_NORMAL);
    }
}



/*===========================================================================*/
/* invert a given area                                                       */
/*===========================================================================*/
void InvertGrayRect(int x0,int y0,int x1, int y1) {
    int p;
    SCR_RECT sr = {x0,y0,x1,y1};

    for (p=0;p<2;p++) {
        SetPlane(p);
        ScrRectFill(&sr,&fullscreen,A_XOR);
    }
}



/*===========================================================================*/
/* draws a popup window                                                      */
/*===========================================================================*/
void DrawPopup(int x0,int y0,int x1, int y1) {
    DrawColorRect(x0,y0,x1,y1,COLOR_BLACK,RECT_EMPTY);
    x0++,y0++,x1--,y1--;
    DrawColorRect(x0,y0,x1,y1,COLOR_DARKGRAY,RECT_EMPTY);
    x0++,y0++,x1--,y1--;
    DrawColorRect(x0,y0,x1,y1,COLOR_LIGHTGRAY,RECT_EMPTY);
    x0++,y0++,x1--,y1--;
    DrawColorRect(x0,y0,x1,y1,COLOR_WHITE,RECT_FILLED);
}



/*===========================================================================*/
/* utility funcction to draw a string to both planes                         */
/* NOTE: there exists to new styles which are handled as flags               */
/*       A_CENTERED ... the given font will be used and the string will be   */
/*                      drawn centered on the screen                         */
/*       A_SHADOWED ... if this flag is set in the attributes a lightgray    */
/*                      shadow will be drawn with +1 pixel offset in all     */
/*                      two directions                                       */
/*===========================================================================*/
void DrawString(int x,int y,char* s,int font,int attr) {
    int do_shadow = attr & A_SHADOWED;

    FontSetSys(font);

    if (attr & A_CENTERED) {
        x = (LCD_WIDTH-DrawStrWidth(s,font))/2;
        attr &= ~A_CENTERED;
    }

    attr &= ~A_SHADOWED;

    SetPlane(DARK_PLANE);
    DrawStr(x,y,s,attr);
    SetPlane(LIGHT_PLANE);
    DrawStr(x,y,s,attr);

    if (do_shadow) DrawStr(x+1,y+1,s,A_NORMAL);
}



//#############################################################################
//###################### NO MORE FAKES BEYOND THIS LINE #######################
//#############################################################################
//
//=============================================================================
// Revision History
//=============================================================================
//
// $Log: generic.c,v $
// Revision 1.2  2000/08/12 15:31:12  Thomas Nussbaumer
// substitution keywords added
//
//
