/******************************************************************************
*
* project name:    TI-Chess
* file name:       menu.c
* initial date:    19/03/2000
* authors:         thomas.nussbaumer@gmx.net (coding)
*                  marcos.lopez@wol.es (design/graphics/beta testing)
* description:     contains the menu system
*
* $Id: menu.c,v 1.4 2000/12/09 15:38:18 Thomas Nussbaumer Exp $
*
******************************************************************************/


#define M_HEIGHT2      44


#if TI92_VERSION

//-----------------------------------------------------------------------------
// constants for TI92 version
//-----------------------------------------------------------------------------
#define M_TSTART_Y     17
#define M_DELTA_Y      10
#define M_CENTERX     120
#define M_CENTERY      57
#define M_WIDTH       140
#define M_WIDTH2       70
#define M_PARAMS1X     55
#define M_PARAMS2X    120
#define M_CSTART_X     53
#define M_CEND_X      187
#define HP_START1X     55
#define HP_START2X    110
#define HP_DELTAY       7

#else

//-----------------------------------------------------------------------------
// constants for TI89 version
//-----------------------------------------------------------------------------
#define M_TSTART_Y      7
#define M_DELTA_Y      10
#define M_CENTERX      80
#define M_CENTERY      47
#define M_WIDTH       140
#define M_WIDTH2       70
#define M_CSTART_X     13
#define M_CEND_X      147
#define M_PARAMS1X     15
#define M_PARAMS2X     80
#define HP_START1X     15
#define HP_START2X     70
#define HP_DELTAY       7

#endif


defaults_t defaults   = {};

extern int  std_depth;          // standard depth
extern int  LoadDefaults(void);
extern int  SaveDefaults(void);

void        HelpMenu(void);
void        ShowMovesMenu(void);
void        AboutMenu(void);
int         ProblemMenu(void);


extern int problem_active;
extern int problem_max;

extern char problem_text1[SIZE_TEXT+1];
extern char problem_text2[SIZE_TEXT+1];
extern char problem_text3[SIZE_TEXT+1];
extern char problem_copyright[SIZE_COPYRIGHT+1];

extern void LoadProblemDesc();



/*===========================================================================*/
/* draws menu area with border                                               */
/*===========================================================================*/
void InitCenterMenu() {
    DrawPopup(M_CENTERX-M_WIDTH2-1,M_CENTERY-M_HEIGHT2-1,
              M_CENTERX+M_WIDTH2+1,M_CENTERY+M_HEIGHT2+8);
}


int  main_idx      = 0;
int  loadsave_idx  = 0;

#if TI89_VERSION
int  main_coords[] = {0,15, 19,55,  59,77,  81,105, 109,124, 126,145, 147,159};
#else
int  main_coords[] = {0,15, 31,67, 83,101, 117,141, 157,172, 188,207, 223,236};
#endif



/*===========================================================================*/
/* inverts an entry of the loadsave pull down menu                           */
/*===========================================================================*/
void InvertOptionEntry(int index) {
    int x = OFFSET_X-2+3+main_coords[3*2];
    int y = OFFSET_Y+11+index*7;
    InvertGrayRect(x,y,x+46,y+6);
}



char* options[7] = {"Strength","AutoLoad","AutoSave",
                    "Hashing","Requests","Save Mvs","PieceSet"};



/*===========================================================================*/
/* handles the option menu                                                   */
/*===========================================================================*/
void OptionMenu(void) {
    int   startx1 = OFFSET_X-2+main_coords[3*2];
    int   startx2 = startx1 + 34 + 3;
    int   y       = OFFSET_Y+8;
    char *s;
    char *s2;
    char *state[2]    = { "ON","OFF" };
    char  level[3]    = {'L','1',0};
    char  pieceset[2] = {'1',0};
    int   i;
    int   read;

    DrawPopup(startx1,y,startx1+52,y+47+7);

    y+=4;
    startx1+=3;

    for (i=0;i<7;i++) {
        DrawString(startx1,y,options[i],F_4x6,A_REPLACE);

        switch(i) {
           case 0: level[1] = '1'+defaults.strength;
                   s = level;
                   break;
           case 1: s = state[defaults.autoload];
                   break;
           case 2: s = state[defaults.autosave];
                   break;
           case 3: s = state[defaults.hashtables];
                   break;
           case 4: s = state[defaults.requests];
                   break;
           case 5: s = state[defaults.savemoves];
                   break;
           case 6: pieceset[0] = '1'+defaults.pieceset;
                   s = pieceset;
                   break;
        }
        DrawString(startx2,y,s,F_4x6,A_REPLACE);
        y+=7;
    }

    InvertOptionEntry(0);
    i = 0;

    do {
        if ((read = GetUserInput(0))==KEY_ESCAPE) break;
        
        switch(read) {
            case KEY_MUP:
                InvertOptionEntry(i);
                if (i==0) {
                    read = KEY_ESCAPE;
                    break;
                }
                i--;
                InvertOptionEntry(i);
                break;
            case KEY_MDOWN:
                if (i==6) break;
                InvertOptionEntry(i);
                i++;
                InvertOptionEntry(i);
                break;
            case KEY_MLEFT:
                if (i==0) {
                    if (defaults.strength > 0) {
                        defaults.strength--;
                        y = OFFSET_Y+12+i*7;
                        DrawString(startx2,y,level,F_4x6,A_NORMAL);
                        level[1] = '1'+(char)defaults.strength;
                        DrawString(startx2,y,level,F_4x6,A_REVERSE);
                    }
                    break;
                }
                if (i==6) {
                    if (defaults.pieceset > 0) {
                        defaults.pieceset--;
                        y = OFFSET_Y+12+i*7;
                        DrawString(startx2,y,pieceset,F_4x6,A_NORMAL);
                        pieceset[0] = '1'+(char)defaults.pieceset;
                        DrawString(startx2,y,pieceset,F_4x6,A_REVERSE);
                    }
                    break;
                }
                // else: !!!! FALLTHROUGH !!!!
            case KEY_MRIGHT:
                if (i==0) {
                    if (defaults.strength < 4) {
                        defaults.strength++;
                        y = OFFSET_Y+12+i*7;
                        DrawString(startx2,y,level,F_4x6,A_NORMAL);
                        level[1] = '1'+(char)defaults.strength;
                        DrawString(startx2,y,level,F_4x6,A_REVERSE);
                    }
                    break;
                }
                if (i==6) {
                    if (defaults.pieceset < 1) {
                        defaults.pieceset++;
                        y = OFFSET_Y+12+i*7;
                        DrawString(startx2,y,pieceset,F_4x6,A_NORMAL);
                        pieceset[0] = '1'+(char)defaults.pieceset;
                        DrawString(startx2,y,pieceset,F_4x6,A_REVERSE);
                    }
                    break;
                }

                switch(i) {
                   case 1: s2 = state[defaults.autoload];
                           if (defaults.autoload) defaults.autoload = 0;
                           else                   defaults.autoload = 1;
                           s = state[defaults.autoload];
                           break;
                   case 2: s2 = state[defaults.autosave];
                           if (defaults.autosave) defaults.autosave = 0;
                           else                   defaults.autosave  = 1;
                           s = state[defaults.autosave];
                           break;
                   case 3: s2 = state[defaults.hashtables];
                           if (defaults.hashtables) defaults.hashtables = 0;
                           else                     defaults.hashtables = 1;
                           s = state[defaults.hashtables];
                           break;
                   case 4: s2 = state[defaults.requests];
                           if (defaults.requests) defaults.requests = 0;
                           else                   defaults.requests = 1;
                           s = state[defaults.requests];
                           break;
                   case 5: s2 = state[defaults.savemoves];
                           if (defaults.savemoves) defaults.savemoves = 0;
                           else                    defaults.savemoves = 1;
                           s = state[defaults.savemoves];
                           break;
                }

                y = OFFSET_Y+12+i*7;
                DrawString(startx2,y,s2,F_4x6,A_NORMAL);
                DrawString(startx2,y,s,F_4x6,A_REVERSE);
                break;

        }
    }
    while (read != KEY_ESCAPE && read != KEY_EXIT);
           
    SaveDefaults(); // save defaults to "ticcfg"
    
    std_depth = defaults.strength+1;

    CorrectInfoBoard();
}



/*===========================================================================*/
/* inverts an entry of the loadsave pull down menu                           */
/*===========================================================================*/
void InvertLoadSaveEntry(int index) {
    int x = OFFSET_X-2+3+main_coords[2];
    int y = OFFSET_Y+11+index*7;
    InvertGrayRect(x,y,x+46,y+6);
}



/*===========================================================================*/
/* handles the load save menu                                                */
/*===========================================================================*/
int LoadSaveMenu(void) {
    int   startx = OFFSET_X-2+main_coords[2];
    int   y      = OFFSET_Y+8;
    int   i;
    int   read;

    char *s1 = "LOAD ticsave0";
    char *s2 = "SAVE ticsave1";
    DrawPopup(startx,y,startx+52,y+54+7);

    y+=4;
    startx+=3;
    for (i=0;i<4;i++) {
        s1[12] = '0'+i;
        DrawString(startx,y,s1,F_4x6,A_REPLACE);
        y+=7;
    }

    for (i=0;i<3;i++) {
        s2[12] = '1'+i;
        DrawString(startx,y,s2,F_4x6,A_REPLACE);
        y+=7;
    }

    DrawString(startx,y,"EXPORT Game",F_4x6,A_REPLACE);

    InvertLoadSaveEntry(0);
    i = 0;

    do {
        read = GetUserInput(0);

        switch(read) {
            case KEY_MUP:
                InvertLoadSaveEntry(i);
                if (i==0) return FALSE;
                i--;
                InvertLoadSaveEntry(i);
                break;
            case KEY_MDOWN:
                if (i==7) break;
                InvertLoadSaveEntry(i);
                i++;
                InvertLoadSaveEntry(i);
                break;
            case KEY_ENTER:
                loadsave_idx = i;
                return TRUE;
        }
    }
    while(read != KEY_ESCAPE && read != KEY_EXIT);
    return FALSE;
}



/*===========================================================================*/
/* inverts an entry of the main menu                                         */
/*===========================================================================*/
void InvertMainEntry(int index) {
    InvertGrayRect(OFFSET_X-2+main_coords[index*2],
                   OFFSET_Y+1,
                   OFFSET_X-2+main_coords[index*2+1],
                   OFFSET_Y+1+6);
}



/*===========================================================================*/
/* show main menu                                                            */
/*===========================================================================*/
void DrawMainMenu() {
    int x0 = 0;
    int x1 = LCD_WIDTH-1;
    int y = 0;

    DrawColorLine(x0,y,x1,y,COLOR_BLACK);
    y++;
    DrawColorLine(x0,y,x1,y,COLOR_DARKGRAY);
    y++;
    DrawColorLine(x0,y,x1,y,COLOR_LIGHTGRAY);
    y++;
    DrawColorRect(x0,y,x1,y+6,COLOR_WHITE,RECT_FILLED);
    y++;
#if TI89_VERSION
    DrawString(x0,y,"New  Load/Save  Train  Options  Help About Exit",F_4x6,A_REPLACE);
#else
    DrawString(x0,y,"New        Load/Save        Train        Options        Help        About        Exit",F_4x6,A_REPLACE);
#endif
    y+=6;
    DrawColorLine(x0,y,x1,y,COLOR_LIGHTGRAY);
    y++;
    DrawColorLine(x0,y,x1,y,COLOR_DARKGRAY);
    y++;
    DrawColorLine(x0,y,x1,y,COLOR_BLACK);
    y++;
    InvertMainEntry(main_idx);
}



/*===========================================================================*/
/* show a menu                                                               */
/*===========================================================================*/
int MainMenu(int showmenu) {
    int        i;
    int        read;
    int        end_of_loop = FALSE;
    int        redraw_menu = TRUE;
    LCD_BUFFER LCD_tmp1;
    LCD_BUFFER LCD_tmp2;
    int        p;
    int        y;
    int        retval;
    WIN_RECT   wr;

    memcpy(LCD_tmp1,light_plane,LCD_SIZE);
    memcpy(LCD_tmp2,dark_plane, LCD_SIZE);

    if (showmenu != MENU_NONE) {
        switch(showmenu) {
            case MENU_LOADSAVE:
                if (LoadSaveMenu()) {
                    if (loadsave_idx < 4)      retval = MENU_CMD_LOAD;
                    else if (loadsave_idx < 7) retval = MENU_CMD_SAVE;
                    else                       retval = MENU_CMD_EXPORT;
                }
                else {
                    retval = MENU_NONE;
                }
                break;
            case MENU_HELP:
                HelpMenu();
                retval = MENU_NONE;
                break;
            case MENU_SHOWMOVES:
                ShowMovesMenu();
                retval = MENU_NONE;
                break;
        }
    }
    else {
        do {
            if (redraw_menu) {
                memcpy(light_plane,LCD_tmp2,LCD_SIZE);
                memset(dark_plane,0,LCD_SIZE);
                DrawMainMenu();
                redraw_menu = FALSE;
            }
            read = GetUserInput(0);
            switch(read) {
                case KEY_MLEFT:
                    InvertMainEntry(main_idx);
                    main_idx--;
                    if (main_idx<0) main_idx=6;
                    InvertMainEntry(main_idx);
                    break;
                case KEY_MRIGHT:
                    InvertMainEntry(main_idx);
                    main_idx++;
                    if (main_idx>6) main_idx=0;
                    InvertMainEntry(main_idx);
                    break;
                case KEY_EXIT:
                    retval = MENU_EXIT;
                    end_of_loop = TRUE;
                    break;
                case KEY_ENTER:
                case KEY_MDOWN:
                    switch(main_idx) {
                        case MENU_SETTINGS:
                            OptionMenu();
                            redraw_menu = TRUE;
                            break;
                        case MENU_LOADSAVE:
                            InvertMainEntry(main_idx);
                            if (LoadSaveMenu()) {
                                if (loadsave_idx < 4)      retval = MENU_CMD_LOAD;
                                else if (loadsave_idx < 7) retval = MENU_CMD_SAVE;
                                else                       retval = MENU_CMD_EXPORT;
                                end_of_loop = TRUE;
                            }
                            else {
                                redraw_menu = TRUE;
                            }
                            InvertMainEntry(main_idx);
                            break;
                        case MENU_PROBLEM:
                            if (ProblemMenu()) {
                                retval = MENU_PROBLEM;
                                end_of_loop = TRUE;
                            }
                            else {
                                redraw_menu = TRUE;
                            }
                            break;

                        case MENU_ABOUT:
                            AboutMenu();
                            redraw_menu = TRUE;
                            break;
                        case MENU_HELP:
                            HelpMenu();
                            redraw_menu = TRUE;
                            break;
                        default:
                            retval = main_idx;
                            end_of_loop = TRUE;
                            break;
                    }
                    break;
            }

        }
        while(read != KEY_ESCAPE && !end_of_loop && read != KEY_EXIT);
    }

    memcpy(light_plane,LCD_tmp1,LCD_SIZE);
    memcpy(dark_plane, LCD_tmp2,LCD_SIZE);


    if (read == KEY_ESCAPE) return MENU_NONE;

    return retval;
}



#if TI92_VERSION

//--------------------------------------------
// help page for TI92 version
//--------------------------------------------
const char* helppage[] =
        { "[STO]",       "Load/Save Game",
          "[C]",         "Change Sides",
          "[(][)]",      "Level Down/Up",
          "[A]",         "Toggle Automatic Play",
          "[BACK][B]",   "Take Back a Move",
          "[F]",         "Undo Take Back",
          "[R]",         "Rotate Board",
          "[2]",         "Toggle 2-Player Mode",
          "[F1]",        "==[ENTER]==[Y]",
          "[ESC]",       "==[N] or Main Menu",
          "[S]",         "Show Moves so Far",
          "[F5]",        "Boss Key (EXIT)",
          "[F2][F3]",    "Adjust Grayscales",
          0};

#else

//--------------------------------------------
// help page for TI89 version
//--------------------------------------------
const char* helppage[] =
        {
          "[STO]",     "Load/Save Game",
          "[CATALOG]", "Change Sides",
          "[(][)]",    "Level Down/Up",
          "[0]",       "Automatic Play",
          "[BACK]",    "Take Back a Move",
          "[CLEAR]",   "Undo Take Back",
          "[HOME]",    "Rotate Board",
          "[2]",       "2-Player Mode",
          "[ENTER]",   "==[2ND]==[Y]",
          "[ESC]",     "==[N] or Main Menu",
          "[.]",       "Show Moves so Far",
          "[F5]",      "Boss Key (EXIT)",
          "[F2][F3]",  "Adjust Grayscales",
          0};
#endif



/*===========================================================================*/
/* handles help menu                                                         */
/*===========================================================================*/
void HelpMenu(void) {
    int i=0;

    InitCenterMenu();

    do {
        DrawString(HP_START1X,i/2*HP_DELTAY+M_TSTART_Y-1,(char*)helppage[i],F_4x6,A_REPLACE);
        DrawString(HP_START2X,i/2*HP_DELTAY+M_TSTART_Y-1,(char*)helppage[i+1],F_4x6,A_REPLACE);
        i+=2;
    }
    while (helppage[i] != 0);
    GetUserInput(0);
}



#define LINES_PER_PAGE 12

/*===========================================================================*/
/* lists all stored moves so far                                             */
/*===========================================================================*/
void ShowMovesMenu() {
    int  i  = 0;
    int  mv = move_count-moves_stored;
    char s[50];
    int  counter=0;
    int  inputkey;

    InitCenterMenu();

    if (moves_stored == 0) {
        DrawString(HP_START1X,M_TSTART_Y-1,"No moves stored. Sorry.",F_4x6,A_REPLACE | A_SHADOWED);
        GetUserInput(0);
        return;
    }

    if (mv % 2 == 1) {
        sprintf(s,"[%03d]",mv+1);
        DrawString(HP_START1X,counter*HP_DELTAY+M_TSTART_Y-1,s,F_4x6,A_REPLACE);

        sprintf(s,"%s",Move2Str((move_t*)&move_store[0],FALSE));
        DrawString(HP_START2X,counter*HP_DELTAY+M_TSTART_Y-1,s,F_4x6,A_REPLACE);
        i = 1;
        counter++;
    }

    for (;i<moves_stored;i+=2) {
        if (!counter) InitCenterMenu();
        sprintf(s,"[%03d] %s",mv+i+1,Move2Str((move_t*)&move_store[i],FALSE));
        DrawString(HP_START1X,counter*HP_DELTAY+M_TSTART_Y-1,s,F_4x6,A_REPLACE);
        counter++;

        if (i+1 < moves_stored) {
             sprintf(s,"%s",Move2Str((move_t*)&move_store[i+1],FALSE));
             DrawString(HP_START2X,(counter-1)*HP_DELTAY+M_TSTART_Y-1,s,F_4x6,A_REPLACE);
        }

        if ((counter) % LINES_PER_PAGE == LINES_PER_PAGE-1) {
            if (i<(moves_stored-2)) {
                DrawString(HP_START1X,(LINES_PER_PAGE-1)*HP_DELTAY+M_TSTART_Y-1,
                           "--- Continue with Listing ? ---",F_4x6,A_REPLACE | A_SHADOWED);
                inputkey = GetUserInput(0);
                if (inputkey == KEY_ESCAPE || inputkey == KEY_EXIT) return;
            }
            counter = 0;
        }
    }

    DrawString(HP_START1X,(LINES_PER_PAGE-1)*HP_DELTAY+M_TSTART_Y-1,
               "--- End Of List ---",F_4x6,A_REPLACE | A_SHADOWED);
    GetUserInput(0);
}



/*===========================================================================*/
/* handles about menu                                                        */
/*===========================================================================*/
void AboutMenu(void) {
    InitCenterMenu();
    DrawString(0,M_TSTART_Y+5,   "A TI-Chess Team Production",
               F_4x6,A_REPLACE | A_CENTERED | A_SHADOWED);
    DrawString(0,M_TSTART_Y+15,"Done December/2000 By",
               F_4x6,A_REPLACE | A_CENTERED);
    DrawString(0,M_TSTART_Y+28,"KiLLRoY",
               F_6x8,A_REPLACE | A_CENTERED | A_SHADOWED);
    DrawString(0,M_TSTART_Y+38,"(thomas.nussbaumer@gmx.net)",
               F_4x6,A_REPLACE | A_CENTERED);
    DrawString(0,M_TSTART_Y+53,"And",
               F_4x6,A_REPLACE | A_CENTERED);
    DrawString(0,M_TSTART_Y+65,"MadMark",
               F_6x8,A_REPLACE | A_CENTERED | A_SHADOWED);
    DrawString(0,M_TSTART_Y+75,"(marcos.lopez@wol.es)",
               F_4x6,A_REPLACE | A_CENTERED);
    GetUserInput(0);
}



/*===========================================================================*/
/* handles problem menu                                                      */
/*===========================================================================*/
int ProblemMenu(void) {
    int  read;
    int  redraw = TRUE;
    char tmpbuf[100];

    do {
        if (redraw) {
            InitCenterMenu();
            LoadProblemDesc();

            if (problem_max == -1) {
                DrawString(M_PARAMS1X,M_TSTART_Y,"Problems File Missing",F_6x8,A_REPLACE | A_SHADOWED);
                DrawString(M_PARAMS1X,M_DELTA_Y*2+M_TSTART_Y,"Please Upload TICPRO",F_6x8,A_REPLACE | A_SHADOWED);
                GetUserInput(0);
                return FALSE;
            }

            DrawString(M_PARAMS1X,M_TSTART_Y,"Load Puzzle Nr:",F_6x8,A_REPLACE | A_SHADOWED);
            sprintf(tmpbuf,"%03d",problem_active);
            DrawString(M_PARAMS2X+30,M_TSTART_Y,tmpbuf,F_6x8,A_REPLACE);

            InvertGrayRect(M_CSTART_X,M_TSTART_Y-2,M_CEND_X,M_DELTA_Y+M_TSTART_Y-2);

            DrawString(0,M_DELTA_Y*2+M_TSTART_Y,problem_text1,F_6x8,A_REPLACE | A_CENTERED);
            DrawString(0,M_DELTA_Y*3+M_TSTART_Y,problem_text2,F_6x8,A_REPLACE | A_CENTERED);
            DrawString(0,M_DELTA_Y*4+M_TSTART_Y,problem_text3,F_6x8,A_REPLACE | A_CENTERED);
            DrawString(0,M_DELTA_Y*7+M_TSTART_Y,problem_copyright,F_4x6,A_REPLACE | A_CENTERED);
            redraw = FALSE;
        }
        read = GetUserInput(0);

        switch(read) {
            case KEY_MRIGHT:
                problem_active++;
                if (problem_active > problem_max) {
                    problem_active = 1;
                }
                redraw = TRUE;
                break;
            case KEY_MLEFT:
                problem_active--;
                if (problem_active < 1) {
                    problem_active = problem_max;
                }
                redraw = TRUE;
                break;
        }
    }
    while (read != KEY_ENTER && read != KEY_ESCAPE && read != KEY_MUP && read != KEY_EXIT);

    if (read == KEY_ENTER) return TRUE;
    else                   return FALSE;
}



/*===========================================================================*/
/* handles a the promotion dialog                                            */
/*===========================================================================*/
int PromotionDialog() {
    int read;
    int x;
    int y;
    int i=0;

    LCD_BUFFER LCD_tmp1;
    LCD_BUFFER LCD_tmp2;

    memcpy(LCD_tmp1,light_plane,LCD_SIZE);
    memcpy(LCD_tmp2,dark_plane, LCD_SIZE);

    x = infos[active_board].x-2;
    y = infos[active_board].y-2;


    DrawPopup(x,y,x+57,y+34);
    x+=9;
    y+=6;
    DrawString(x,y,"Promote to:",F_4x6,A_REPLACE);
    y+=11;
    x-=4;

#if TI92_VERSION
    // quick hack to re-align sprite position for TI92 version
    x--;
    y--;
#endif
    if (active_board) {
        // black
        DrawFigure(x,y,B_QUEEN);
        DrawFigure(x+12,y,B_ROOK);
        DrawFigure(x+24,y,B_KNIGHT);
        DrawFigure(x+36,y,B_BISHOP);
    }
    else {
        // white
        DrawFigure(x,y,W_QUEEN);
        DrawFigure(x+12,y,W_ROOK);
        DrawFigure(x+24,y,W_KNIGHT);
        DrawFigure(x+36,y,W_BISHOP);
    }
#if TI92_VERSION
    // quick hack to re-align sprite position for TI92 version
    x++;
    y++;
#endif

    InvertGrayRect(x,y,x+11,y+11);

    do {
        read = GetUserInput(0);
        switch(read) {
            case KEY_MLEFT:
                InvertGrayRect(x+i*12,y,x+i*12+11,y+11);
                i--;
                if (i<0) i=3;
                InvertGrayRect(x+i*12,y,x+i*12+11,y+11);
                break;
            case KEY_MRIGHT:
                InvertGrayRect(x+i*12,y,x+i*12+11,y+11);
                i++;
                if (i>3) i=0;
                InvertGrayRect(x+i*12,y,x+i*12+11,y+11);
                break;
        }
    }
    while (read != KEY_ENTER && read != KEY_EXIT);

    memcpy(light_plane,LCD_tmp1,LCD_SIZE);
    memcpy(dark_plane, LCD_tmp2,LCD_SIZE);
    
    switch(i) {
        case 1:  return 'R';
        case 2:  return 'N';
        case 3:  return 'B';
        default: return 'Q';
    }
}



//#############################################################################
//###################### NO MORE FAKES BEYOND THIS LINE #######################
//#############################################################################
//
//=============================================================================
// Revision History
//=============================================================================
//
// $Log: menu.c,v $
// Revision 1.4  2000/12/09 15:38:18  Thomas Nussbaumer
// grayscale adjustment keys F2/F3 added to help text
//
// Revision 1.3  2000/12/02 15:12:53  Thomas Nussbaumer
// changes due to global plane1/2 renaming
//
// Revision 1.2  2000/08/12 15:31:13  Thomas Nussbaumer
// substitution keywords added
//
//
